aboutsummaryrefslogtreecommitdiffstats
path: root/alc/effects/convolution.cpp
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2020-12-05 14:18:19 -0800
committerChris Robinson <[email protected]>2020-12-05 14:18:19 -0800
commit4ee95dc296e0aea86d4cd091d6b9c47912760da1 (patch)
treeb82a4484732e82d8dc1b3313ed9221cc0ba46576 /alc/effects/convolution.cpp
parent2fc10a2bc02f7368683801c8819f32a8121c6ae4 (diff)
Use a smaller FFT for convolution
Diffstat (limited to 'alc/effects/convolution.cpp')
-rw-r--r--alc/effects/convolution.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/alc/effects/convolution.cpp b/alc/effects/convolution.cpp
index 733a0a27..8914835a 100644
--- a/alc/effects/convolution.cpp
+++ b/alc/effects/convolution.cpp
@@ -102,7 +102,7 @@ struct ChanMap {
using complex_d = std::complex<double>;
-constexpr size_t ConvolveUpdateSize{1024};
+constexpr size_t ConvolveUpdateSize{256};
constexpr size_t ConvolveUpdateSamples{ConvolveUpdateSize / 2};
@@ -513,8 +513,8 @@ void ConvolutionState::process(const size_t samplesToDo,
for(size_t i{m};i < ConvolveUpdateSize;++i)
mFftBuffer[i] = std::conj(mFftBuffer[ConvolveUpdateSize-i]);
/* Apply iFFT to get the 1024 (really 1023) samples for output. The
* 512 output samples are combined with the last output's 511
* second-half samples (and this output's second half is
* subsequently saved for next time).
*/
@@ -513,8 +513,8 @@ void ConvolutionState::process(const size_t samplesToDo,
for(size_t i{m};i < ConvolveUpdateSize;++i)
mFftBuffer[i] = std::conj(mFftBuffer[ConvolveUpdateSize-i]);
- /* Apply iFFT to get the 1024 (really 1023) samples for output. The
- * 512 output samples are combined with the last output's 511
+ /* Apply iFFT to get the 256 (really 255) samples for output. The
+ * 128 output samples are combined with the last output's 127
* second-half samples (and this output's second half is
* subsequently saved for next time).